#!/bin/bash

##
## This script is the preferred way to start scyld-cloud-workstation.  Arguments
## passed to this script are passed directly to the server.
##

# Handle arguments.
ARGS="${@:1}"
DISP=":0"

# find out where this script is stored
SOURCE="${BASH_SOURCE[0]}"
while [ -h "$SOURCE" ]; do # resolve $SOURCE until the file is no longer a symlink
    DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"
    SOURCE="$(readlink "$SOURCE")"
    [[ $SOURCE != /* ]] && SOURCE="$DIR/$SOURCE" # if $SOURCE was a relative symlink, we need to resolve it relative to the path where the symlink file was located
done
BASH_DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"

function clean_exit() {
    popd &> /dev/null
    exit $1
}

##
## Start scyld-cloud-workstation
##
pushd $BASH_DIR &> /dev/null

# Verify display can be opened
xset q -display $DISP &> /dev/null
STATUS=$?

# if we can't open the display
if [ $STATUS -ne 0 ] ; then

    if [ -z "$XAUTHORITY" ]; then
        # ... and XAUTHORITY isn't set ...
        # Get the path of the X '-auth' argument.  This fails if a whitespace is in the path.
        XA=`ps ww -C X,Xorg -o args= --sort=-stime | grep " $DISP" | grep -m 1 -o '[-]auth [^ ]*' | cut -d " " -f 2`
        if [ -f $XA ] && [ -r $XA ] && [ ! "$XA" = "" ] ; then
            export XAUTHORITY=$XA
        else
            # Gnome 3+ does not have the display number in the command line
            XA=`ps ww -C X,Xorg -o args= --sort=-stime | grep -m 1 -o '[-]auth [^ ]*' | cut -d " " -f 2`
            if [ -f $XA ] && [ -r $XA ]; then
                export XAUTHORITY=$XA
                # We are now authenticated.  Now find the display.
                for idx in `seq 0 42`
                do
                    DISP=":"$idx
                    xset q -display $DISP &> /dev/null
                    STATUS=$?
                    if [ $STATUS -eq 0 ] ; then
                        break;
                    fi
                done

                if [ "$DISP" = ":42" ] ; then
                    echo "Can't start scyld-cloud-workstation: Can't autodetect X display.  Verify that X is running and that Xauthority is configured for the X display (see the documentation FAQ for more on Xauthority)."
                    clean_exit $STATUS
                fi
            else
                echo "Can't start scyld-cloud-workstation: Can't autodetect XAUTHORITY for display \"$DISP\"."
                clean_exit $STATUS
            fi
        fi
    else
        # ... and XAUTHORITY is set ...
        # We need to find the proper display
        for idx in 0 1 42
        do
            DISP=":"$idx
            xset q -display $DISP &> /dev/null
            STATUS=$?
            if [ $STATUS -eq 0 ] ; then
                break;
            fi
        done

        if [ "$DISP" = ":42" ] ; then
            echo "Can't start scyld-cloud-workstation: Can't autodetect X display.  Verify that X is running and that Xauthority (\"$XAUTHORITY\") is configured for the X display (see the documentation FAQ for more on Xauthority)."
            clean_exit $STATUS
        fi
    fi
fi

xset q -display $DISP &> /dev/null
STATUS=$?
if [ $STATUS -eq 0 ]; then
    env DISPLAY=$DISP ./scyld-cloud-workstation $ARGS
    STATUS=$?
else
    echo "Can't start scyld-cloud-workstation: Can't open display \"$DISP\"."
fi
clean_exit $STATUS
